@@ -27,6 +27,9 @@
 
 from u2flib_host import u2f_v2
 from u2flib_host import hid_transport
+from u2flib_host.yubicommon.compat import string_types
+
+import json
 
 TRANSPORTS = [
     hid_transport
@@ -48,27 +51,24 @@ def list_devices():
     return devices
 
 
-def get_lib(data):
-    return LIB_VERSIONS[data.get('version', 'U2F_V2')]
+def get_lib(device, data):
+    if isinstance(data, string_types):
+        data = json.loads(data)
 
-
-def register(device, data, facet):
-    version = data.get('version')
-    if version not in device.get_supported_versions():
-        raise ValueError("Device does not support U2F version: %s" % version)
-    if version not in LIB_VERSIONS:
-        raise ValueError("Library does not support U2F version: %s" % version)
-
-    lib = LIB_VERSIONS[version]
-    return lib.register(device, data, facet)
-
-
-def authenticate(device, data, facet, check_only=False):
     version = data['version']
     if version not in device.get_supported_versions():
         raise ValueError("Device does not support U2F version: %s" % version)
     if version not in LIB_VERSIONS:
         raise ValueError("Library does not support U2F version: %s" % version)
 
-    lib = LIB_VERSIONS[version]
+    return LIB_VERSIONS[version]
+
+
+def register(device, data, facet):
+    lib = get_lib(device, data)
+    return lib.register(device, data, facet)
+
+
+def authenticate(device, data, facet, check_only=False):
+    lib = get_lib(device, data)
     return lib.authenticate(device, data, facet, check_only)
